tools

package module
v1.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 13, 2025 License: BSD-3-Clause Imports: 4 Imported by: 1

README

Fyne CLI tools

Toolchain and helpful commands for building and managing Fyne apps.

Installation

Using the standard go tools you can install Fyne's command line tool using:

go install fyne.io/tools/cmd/fyne@latest

Synopsis

To list all available commands enter fyne help:

NAME:
   fyne - A command line helper for various Fyne tools.

USAGE:
   fyne [global options] command [command options]

DESCRIPTION:
   The fyne command provides tooling for fyne applications and to assist in their development.

COMMANDS:
   init             Initializes a new Fyne project
   env, e           Prints the Fyne module and environment information
   build, b         Builds an application
   package, p       Packages an application for distribution
   release, r       Prepares an application for public distribution
   install, get, i  Packages and installs an application
   serve, s         Packages an application using WebAssembly and exposes it via a web server
   translate, t     Scans for new translation strings
   version, v       Shows version information for fyne
   bundle           Embeds static content into your go application
   help, h          Shows a list of commands or help for one command

GLOBAL OPTIONS:
   --help, -h  show help

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CommandInShell

func CommandInShell(cmd stringLiteral, args ...string) *exec.Cmd

CommandInShell sets up a new command with the environment set up by user's environment. In darwin or other Unix systems the shell will be loaded by running the terminal and accessing env command. The command is run directly so stdout and stderr can be read directly from the returned `exec.Cmd`. The cmd parameter must be a string constant to avoid possible code injection attacks.

Types

This section is empty.

Directories

Path Synopsis
cmd
fyne command
Run a command line helper for various Fyne tools.
Run a command line helper for various Fyne tools.
fyne/internal/mobile
Package mobile is a partial clone of the golang.org/x/mobile/cmd/gomobile package.
Package mobile is a partial clone of the golang.org/x/mobile/cmd/gomobile package.
fyne/internal/mobile/binres
Package binres implements encoding and decoding of android binary resources.
Package binres implements encoding and decoding of android binary resources.
fyne/internal/mobile/gendex command
Gendex generates a dex file used by Go apps created with gomobile.
Gendex generates a dex file used by Go apps created with gomobile.

Jump to